@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2019 Sean Davis <bluesabre@xfce.org>
+#   Copyright (C) 2012-2020 Sean Davis <bluesabre@xfce.org>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -16,6 +16,10 @@
 #   You should have received a copy of the GNU General Public License along
 #   with this program.  If not, see <https://www.gnu.org/licenses/>.
 
+# pylint: disable=C0114
+# pylint: disable=C0116
+# pylint: disable=C0413
+
 import logging
 
 import gi
@@ -24,10 +28,10 @@ from gi.repository import Gtk
 
 from catfish_lib.PrefsDialog import PrefsDialog
 
-logger = logging.getLogger('catfish')
+LOGGER = logging.getLogger('catfish')
 
 
-# See catfish_lib.AboutDialog.py for more details about how this class works.
+# See catfish_lib.PrefsDialog.py for more details about how this class works.
 class CatfishPrefsDialog(PrefsDialog):
 
     """Creates the about dialog for catfish"""
@@ -50,6 +54,8 @@ class CatfishPrefsDialog(PrefsDialog):
             self.builder.get_object("do_show_sidebar").set_active(True)
         if self.settings.get_setting("close-after-select"):
             self.builder.get_object("close_after_select").set_active(True)
+        if self.settings.get_setting("search-compressed-files"):
+            self.builder.get_object("search_in_compressed_files").set_active(True)
         self.set_exclude_directories(
             self.settings.get_setting("exclude-paths"))
         self.process_events = True
@@ -93,14 +99,23 @@ class CatfishPrefsDialog(PrefsDialog):
             self.settings.set_setting("close-after-select", False)
         self.changed_properties.append("close-after-select")
 
-    def on_add_directory_clicked(self, widget):
+    def on_search_in_compressed_files_toggled(self, widget):
+        if not self.process_events:
+            return
+        if widget.get_active():
+            self.settings.set_setting("search-compressed-files", True)
+        else:
+            self.settings.set_setting("search-compressed-files", False)
+        self.changed_properties.append("search-compressed-files")
+
+    def on_add_directory_clicked(self, widget):  # pylint: disable=W0613
         dlg = Gtk.FileChooserDialog("Add Excluded Directory",
                                     self,
                                     Gtk.FileChooserAction.SELECT_FOLDER,
                                     (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
                                      Gtk.STOCK_OPEN, Gtk.ResponseType.OK))
         response = dlg.run()
-        if (response == Gtk.ResponseType.OK):
+        if response == Gtk.ResponseType.OK:
             path = dlg.get_filename()
             treeview = self.builder.get_object("exclude_treeview")
             model = treeview.get_model()
@@ -108,7 +123,7 @@ class CatfishPrefsDialog(PrefsDialog):
             self.treemodel_to_settings(model)
         dlg.destroy()
 
-    def on_remove_directory_clicked(self, widget):
+    def on_remove_directory_clicked(self, widget):  # pylint: disable=W0613
         treeview = self.builder.get_object("exclude_treeview")
         model = treeview.get_model()
         sel = treeview.get_selection().get_selected()
